=======
Credits
=======

Development
-----------

* Leonardo Alvarado <lalvarad@awi.de>
* Mariana A. Soppa <msoppa@awi.de>
* Brenner Silva

Contributors
------------

Daniel Scheffler, GFZ
Niklas Bohn, GFZ
